@@ -279,8 +279,6 @@ impl_Bonobo_Canvas_Component_update (PortableServer_Servant     servant,
 	return cuta;
 }
 
-static GdkGC *the_gc;
-
 static void
 impl_Bonobo_Canvas_Component_realize (PortableServer_Servant  servant,
 				      const CORBA_char       *window,
@@ -297,7 +295,6 @@ impl_Bonobo_Canvas_Component_realize (PortableServer_Servant  servant,
 		return;
 	}
 
-	the_gc = gdk_gc_new (gdk_window);
 	item->canvas->layout.bin_window = gdk_window;
 	ICLASS (item)->realize (item);
 }
@@ -1044,15 +1041,12 @@ GnomeCanvas *
 bonobo_canvas_new (gboolean is_aa, Bonobo_Canvas_ComponentProxy proxy)
 {
 	GnomeCanvas *canvas;
-	GnomeCanvasItem *orig_root;
 
 	if (is_aa)
 		canvas = GNOME_CANVAS (gnome_canvas_new_aa ());
 	else
 		canvas = GNOME_CANVAS (gnome_canvas_new ());
 
-	orig_root = canvas->root;
-
 	canvas->root = GNOME_CANVAS_ITEM (root_item_hack_new (canvas, proxy));
 
         /* A hack to prevent gtkwidget from issuing a warning about there not
@@ -1231,7 +1225,7 @@ bonobo_canvas_component_factory_init (BonoboCanvasComponentFactory *factory)
 BONOBO_TYPE_FUNC_FULL (BonoboCanvasComponentFactory,
                        Bonobo_CanvasComponentFactory,
                        BONOBO_TYPE_X_OBJECT,
-                       bonobo_canvas_component_factory);
+                       bonobo_canvas_component_factory)
 
 /**
  * bonobo_canvas_component_factory_new:
