@@ -11,9 +11,11 @@
 #ifndef _BONOBO_UI_TOOLBAR_TOGGLE_BUTTON_ITEM_H_
 #define _BONOBO_UI_TOOLBAR_TOGGLE_BUTTON_ITEM_H_
 
-#include <glib/gmacros.h>
+#include <glib.h>
 #include "bonobo-ui-toolbar-button-item.h"
 
+#ifndef BONOBO_UI_DISABLE_DEPRECATED
+
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_UI_TOOLBAR_TOGGLE_BUTTON_ITEM             (bonobo_ui_toolbar_toggle_button_item_get_type ())
@@ -51,4 +53,6 @@ gboolean  bonobo_ui_toolbar_toggle_button_item_get_active  (BonoboUIToolbarToggl
 
 G_END_DECLS
 
+#endif /* BONOBO_UI_DISABLE_DEPRECATED */
+
 #endif /* _BONOBO_UI_TOOLBAR_TOGGLE_BUTTON_ITEM_H_ */
