@@ -11,8 +11,8 @@
 #ifndef _BONOBO_UI_TOOLBAR_H_
 #define _BONOBO_UI_TOOLBAR_H_
 
-#include <glib/gmacros.h>
-#include <gtk/gtkcontainer.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 #include "bonobo-ui-toolbar-item.h"
 
 #ifndef BONOBO_UI_DISABLE_DEPRECATED
@@ -77,7 +77,7 @@ GList                *bonobo_ui_toolbar_get_children     (BonoboUIToolbar      *
 
 G_END_DECLS
 
-#endif
+#endif /* BONOBO_UI_DISABLE_DEPRECATED */
 
 #endif /* _BONOBO_UI_TOOLBAR_H_ */
 
